@@ -39,25 +39,27 @@ private:
     typedef Eigen::Matrix<Scalar, 1, Eigen::Dynamic> RowVector;
     typedef Eigen::Array<Scalar, Eigen::Dynamic, 1> Array;
 
+    typedef typename Matrix::Index Index;
+
     typedef Eigen::Ref<Matrix> GenericMatrix;
     typedef const Eigen::Ref<const Matrix> ConstGenericMatrix;
 
 protected:
-    int n;
-    Matrix mat_T;
+    Index m_n;
+    Matrix m_mat_T;
     // Gi = [ cos[i]  sin[i]]
     //      [-sin[i]  cos[i]]
     // Q = G1 * G2 * ... * G_{n-1}
-    Array rot_cos;
-    Array rot_sin;
-    bool computed;
+    Array m_rot_cos;
+    Array m_rot_sin;
+    bool m_computed;
 public:
     ///
     /// Default constructor. Computation can
     /// be performed later by calling the compute() method.
     ///
     UpperHessenbergQR() :
-        n(0), computed(false)
+        m_n(0), m_computed(false)
     {}
 
     ///
@@ -71,11 +73,11 @@ public:
     /// the matrix are used.
     ///
     UpperHessenbergQR(ConstGenericMatrix &mat) :
-        n(mat.rows()),
-        mat_T(n, n),
-        rot_cos(n - 1),
-        rot_sin(n - 1),
-        computed(false)
+        m_n(mat.rows()),
+        m_mat_T(m_n, m_n),
+        m_rot_cos(m_n - 1),
+        m_rot_sin(m_n - 1),
+        m_computed(false)
     {
         compute(mat);
     }
@@ -91,33 +93,33 @@ public:
     ///
     virtual void compute(ConstGenericMatrix &mat)
     {
-        n = mat.rows();
-        mat_T.resize(n, n);
-        rot_cos.resize(n - 1);
-        rot_sin.resize(n - 1);
+        m_n = mat.rows();
+        m_mat_T.resize(m_n, m_n);
+        m_rot_cos.resize(m_n - 1);
+        m_rot_sin.resize(m_n - 1);
 
-        std::copy(mat.data(), mat.data() + mat.size(), mat_T.data());
+        std::copy(mat.data(), mat.data() + mat.size(), m_mat_T.data());
 
         Scalar xi, xj, r, c, s, eps = std::numeric_limits<Scalar>::epsilon();
         Scalar *Tii, *ptr;
-        for(int i = 0; i < n - 1; i++)
+        for(Index i = 0; i < m_n - 1; i++)
         {
-            Tii = &mat_T(i, i);
+            Tii = &m_mat_T(i, i);
 
             // Make sure mat_T is upper Hessenberg
             // Zero the elements below mat_T(i + 1, i)
-            std::fill(Tii + 2, Tii + n - i, Scalar(0));
+            std::fill(Tii + 2, Tii + m_n - i, Scalar(0));
 
             xi = Tii[0];  // mat_T(i, i)
             xj = Tii[1];  // mat_T(i + 1, i)
             r = std::sqrt(xi * xi + xj * xj);
             if(r <= eps)
             {
-                rot_cos[i] = c = 1;
-                rot_sin[i] = s = 0;
+                m_rot_cos[i] = c = 1;
+                m_rot_sin[i] = s = 0;
             } else {
-                rot_cos[i] = c = xi / r;
-                rot_sin[i] = s = -xj / r;
+                m_rot_cos[i] = c = xi / r;
+                m_rot_sin[i] = s = -xj / r;
             }
             // For a complete QR decomposition,
             // we first obtain the rotation matrix
@@ -126,11 +128,11 @@ public:
             // and then do T[i:(i + 1), i:(n - 1)] = G' * T[i:(i + 1), i:(n - 1)]
 
             // Gt << c, -s, s, c;
-            // mat_T.block(i, i, 2, n - i) = Gt * mat_T.block(i, i, 2, n - i);
-            Tii[0] = r;    // mat_T(i, i)     => r
-            Tii[1] = 0;    // mat_T(i + 1, i) => 0
-            ptr = Tii + n; // mat_T(i, k), k = i+1, i+2, ..., n-1
-            for(int j = i + 1; j < n; j++, ptr += n)
+            // m_mat_T.block(i, i, 2, m_n - i) = Gt * m_mat_T.block(i, i, 2, m_n - i);
+            Tii[0] = r;    // m_mat_T(i, i)     => r
+            Tii[1] = 0;    // m_mat_T(i + 1, i) => 0
+            ptr = Tii + m_n; // m_mat_T(i, k), k = i+1, i+2, ..., n-1
+            for(Index j = i + 1; j < m_n; j++, ptr += m_n)
             {
                 Scalar tmp = ptr[0];
                 ptr[0] = c * tmp - s * ptr[1];
@@ -140,11 +142,11 @@ public:
             // If we do not need to calculate the R matrix, then
             // only the cos and sin sequences are required.
             // In such case we only update T[i + 1, (i + 1):(n - 1)]
-            // mat_T.block(i + 1, i + 1, 1, n - i - 1) *= c;
-            // mat_T.block(i + 1, i + 1, 1, n - i - 1) += s * mat_T.block(i, i + 1, 1, n - i - 1);
+            // m_mat_T.block(i + 1, i + 1, 1, m_n - i - 1) *= c;
+            // m_mat_T.block(i + 1, i + 1, 1, m_n - i - 1) += s * mat_T.block(i, i + 1, 1, m_n - i - 1);
         }
 
-        computed = true;
+        m_computed = true;
     }
 
     ///
@@ -156,10 +158,10 @@ public:
     ///
     Matrix matrix_R()
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
-        return mat_T;
+        return m_mat_T;
     }
 
     ///
@@ -171,15 +173,15 @@ public:
     ///
     virtual Matrix matrix_RQ()
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
         // Make a copy of the R matrix
-        Matrix RQ = mat_T.template triangularView<Eigen::Upper>();
+        Matrix RQ = m_mat_T.template triangularView<Eigen::Upper>();
 
-        Scalar *c = rot_cos.data(),
-               *s = rot_sin.data();
-        for(int i = 0; i < n - 1; i++)
+        Scalar *c = m_rot_cos.data(),
+               *s = m_rot_sin.data();
+        for(Index i = 0; i < m_n - 1; i++)
         {
             // RQ[, i:(i + 1)] = RQ[, i:(i + 1)] * Gi
             // Gi = [ cos[i]  sin[i]]
@@ -187,8 +189,8 @@ public:
 
             Scalar *Yi, *Yi1;
             Yi = &RQ(0, i);
-            Yi1 = Yi + n;  // RQ(0, i + 1)
-            for(int j = 0; j < i + 2; j++)
+            Yi1 = Yi + m_n;  // RQ(0, i + 1)
+            for(Index j = 0; j < i + 2; j++)
             {
                 Scalar tmp = Yi[j];
                 Yi[j]  = (*c) * tmp - (*s) * Yi1[j];
@@ -216,18 +218,18 @@ public:
     // Y -> QY = G1 * G2 * ... * Y
     void apply_QY(Vector &Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
         Scalar tmp;
-        for(int i = n - 2; i >= 0; i--)
+        for(Index i = m_n - 2; i >= 0; i--)
         {
             // Y[i:(i + 1)] = Gi * Y[i:(i + 1)]
             // Gi = [ cos[i]  sin[i]]
             //      [-sin[i]  cos[i]]
             tmp      = Y[i];
-            Y[i]     =  rot_cos[i] * tmp + rot_sin[i] * Y[i + 1];
-            Y[i + 1] = -rot_sin[i] * tmp + rot_cos[i] * Y[i + 1];
+            Y[i]     =  m_rot_cos[i] * tmp + m_rot_sin[i] * Y[i + 1];
+            Y[i + 1] = -m_rot_sin[i] * tmp + m_rot_cos[i] * Y[i + 1];
         }
     }
 
@@ -242,18 +244,18 @@ public:
     // Y -> Q'Y = G_{n-1}' * ... * G2' * G1' * Y
     void apply_QtY(Vector &Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
         Scalar tmp;
-        for(int i = 0; i < n - 1; i++)
+        for(Index i = 0; i < m_n - 1; i++)
         {
             // Y[i:(i + 1)] = Gi' * Y[i:(i + 1)]
             // Gi = [ cos[i]  sin[i]]
             //      [-sin[i]  cos[i]]
             tmp      = Y[i];
-            Y[i]     = rot_cos[i] * tmp - rot_sin[i] * Y[i + 1];
-            Y[i + 1] = rot_sin[i] * tmp + rot_cos[i] * Y[i + 1];
+            Y[i]     = m_rot_cos[i] * tmp - m_rot_sin[i] * Y[i + 1];
+            Y[i + 1] = m_rot_sin[i] * tmp + m_rot_cos[i] * Y[i + 1];
         }
     }
 
@@ -269,13 +271,13 @@ public:
     // Y -> QY = G1 * G2 * ... * Y
     void apply_QY(GenericMatrix Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
-        Scalar *c = rot_cos.data() + n - 2,
-               *s = rot_sin.data() + n - 2;
+        Scalar *c = m_rot_cos.data() + m_n - 2,
+               *s = m_rot_sin.data() + m_n - 2;
         RowVector Yi(Y.cols()), Yi1(Y.cols());
-        for(int i = n - 2; i >= 0; i--)
+        for(Index i = m_n - 2; i >= 0; i--)
         {
             // Y[i:(i + 1), ] = Gi * Y[i:(i + 1), ]
             // Gi = [ cos[i]  sin[i]]
@@ -301,13 +303,13 @@ public:
     // Y -> Q'Y = G_{n-1}' * ... * G2' * G1' * Y
     void apply_QtY(GenericMatrix Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
-        Scalar *c = rot_cos.data(),
-               *s = rot_sin.data();
+        Scalar *c = m_rot_cos.data(),
+               *s = m_rot_sin.data();
         RowVector Yi(Y.cols()), Yi1(Y.cols());
-        for(int i = 0; i < n - 1; i++)
+        for(Index i = 0; i < m_n - 1; i++)
         {
             // Y[i:(i + 1), ] = Gi' * Y[i:(i + 1), ]
             // Gi = [ cos[i]  sin[i]]
@@ -333,13 +335,13 @@ public:
     // Y -> YQ = Y * G1 * G2 * ...
     void apply_YQ(GenericMatrix Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
-        Scalar *c = rot_cos.data(),
-               *s = rot_sin.data();
+        Scalar *c = m_rot_cos.data(),
+               *s = m_rot_sin.data();
         /*Vector Yi(Y.rows());
-        for(int i = 0; i < n - 1; i++)
+        for(Index i = 0; i < m_n - 1; i++)
         {
             // Y[, i:(i + 1)] = Y[, i:(i + 1)] * Gi
             // Gi = [ cos[i]  sin[i]]
@@ -351,12 +353,12 @@ public:
             s++;
         }*/
         Scalar *Y_col_i, *Y_col_i1;
-        int nrow = Y.rows();
-        for(int i = 0; i < n - 1; i++)
+        Index nrow = Y.rows();
+        for(Index i = 0; i < m_n - 1; i++)
         {
             Y_col_i  = &Y(0, i);
             Y_col_i1 = &Y(0, i + 1);
-            for(int j = 0; j < nrow; j++)
+            for(Index j = 0; j < nrow; j++)
             {
                 Scalar tmp = Y_col_i[j];
                 Y_col_i[j]  = (*c) * tmp - (*s) * Y_col_i1[j];
@@ -379,13 +381,13 @@ public:
     // Y -> YQ' = Y * G_{n-1}' * ... * G2' * G1'
     void apply_YQt(GenericMatrix Y)
     {
-        if(!computed)
+        if(!m_computed)
             throw std::logic_error("UpperHessenbergQR: need to call compute() first");
 
-        Scalar *c = rot_cos.data() + n - 2,
-               *s = rot_sin.data() + n - 2;
+        Scalar *c = m_rot_cos.data() + m_n - 2,
+               *s = m_rot_sin.data() + m_n - 2;
         Vector Yi(Y.rows());
-        for(int i = n - 2; i >= 0; i--)
+        for(Index i = m_n - 2; i >= 0; i--)
         {
             // Y[, i:(i + 1)] = Y[, i:(i + 1)] * Gi'
             // Gi = [ cos[i]  sin[i]]
@@ -415,6 +417,8 @@ private:
     typedef Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> Matrix;
     typedef const Eigen::Ref<const Matrix> ConstGenericMatrix;
 
+    typedef typename Matrix::Index Index;
+
 public:
     ///
     /// Default constructor. Computation can
@@ -451,24 +455,24 @@ public:
     ///
     void compute(ConstGenericMatrix &mat)
     {
-        this->n = mat.rows();
-        this->mat_T.resize(this->n, this->n);
-        this->rot_cos.resize(this->n - 1);
-        this->rot_sin.resize(this->n - 1);
+        this->m_n = mat.rows();
+        this->m_mat_T.resize(this->m_n, this->m_n);
+        this->m_rot_cos.resize(this->m_n - 1);
+        this->m_rot_sin.resize(this->m_n - 1);
 
-        this->mat_T.setZero();
-        this->mat_T.diagonal() = mat.diagonal();
-        this->mat_T.diagonal(1) = mat.diagonal(-1);
-        this->mat_T.diagonal(-1) = mat.diagonal(-1);
+        this->m_mat_T.setZero();
+        this->m_mat_T.diagonal() = mat.diagonal();
+        this->m_mat_T.diagonal(1) = mat.diagonal(-1);
+        this->m_mat_T.diagonal(-1) = mat.diagonal(-1);
 
         // A number of pointers to avoid repeated address calculation
-        Scalar *Tii = this->mat_T.data(),  // pointer to T[i, i]
+        Scalar *Tii = this->m_mat_T.data(),  // pointer to T[i, i]
                *ptr,                       // some location relative to Tii
-               *c = this->rot_cos.data(),  // pointer to the cosine vector
-               *s = this->rot_sin.data(),  // pointer to the sine vector
+               *c = this->m_rot_cos.data(),  // pointer to the cosine vector
+               *s = this->m_rot_sin.data(),  // pointer to the sine vector
                r, tmp,
                eps = std::numeric_limits<Scalar>::epsilon();
-        for(int i = 0; i < this->n - 2; i++)
+        for(Index i = 0; i < this->m_n - 2; i++)
         {
             // Tii[0] == T[i, i]
             // Tii[1] == T[i + 1, i]
@@ -496,19 +500,19 @@ public:
             // Update T[i, i + 1] and T[i + 1, i + 1]
             // ptr[0] == T[i, i + 1]
             // ptr[1] == T[i + 1, i + 1]
-            ptr = Tii + this->n;
+            ptr = Tii + this->m_n;
             tmp = *ptr;
             ptr[0] = (*c) * tmp - (*s) * ptr[1];
             ptr[1] = (*s) * tmp + (*c) * ptr[1];
             // Update T[i, i + 2] and T[i + 1, i + 2]
             // ptr[0] == T[i, i + 2] == 0
             // ptr[1] == T[i + 1, i + 2]
-            ptr += this->n;
+            ptr += this->m_n;
             ptr[0] = -(*s) * ptr[1];
             ptr[1] *= (*c);
 
             // Move from T[i, i] to T[i + 1, i + 1]
-            Tii += this->n + 1;
+            Tii += this->m_n + 1;
             // Increase c and s by 1
             c++;
             s++;
@@ -517,8 +521,8 @@ public:
             // If we do not need to calculate the R matrix, then
             // only the cos and sin sequences are required.
             // In such case we only update T[i + 1, (i + 1):(i + 2)]
-            // this->mat_T(i + 1, i + 1) = (*c) * this->mat_T(i + 1, i + 1) + (*s) * this->mat_T(i, i + 1);
-            // this->mat_T(i + 1, i + 2) *= (*c);
+            // this->m_mat_T(i + 1, i + 1) = (*c) * this->mat_T(i + 1, i + 1) + (*s) * this->m_mat_T(i, i + 1);
+            // this->m_mat_T(i + 1, i + 2) *= (*c);
         }
         // For i = n - 2
         r = std::sqrt(Tii[0] * Tii[0] + Tii[1] * Tii[1]);
@@ -532,12 +536,12 @@ public:
         }
         Tii[0] = r;
         Tii[1] = 0;
-        ptr = Tii + this->n;  // points to T[i - 2, i - 1]
+        ptr = Tii + this->m_n;  // points to T[i - 2, i - 1]
         tmp = *ptr;
         ptr[0] = (*c) * tmp - (*s) * ptr[1];
         ptr[1] = (*s) * tmp + (*c) * ptr[1];
 
-        this->computed = true;
+        this->m_computed = true;
     }
 
     ///
@@ -549,25 +553,25 @@ public:
     ///
     Matrix matrix_RQ()
     {
-        if(!this->computed)
+        if(!this->m_computed)
             throw std::logic_error("TridiagQR: need to call compute() first");
 
         // Make a copy of the R matrix
-        Matrix RQ(this->n, this->n);
+        Matrix RQ(this->m_n, this->m_n);
         RQ.setZero();
-        RQ.diagonal() = this->mat_T.diagonal();
-        RQ.diagonal(1) = this->mat_T.diagonal(1);
+        RQ.diagonal() = this->m_mat_T.diagonal();
+        RQ.diagonal(1) = this->m_mat_T.diagonal(1);
 
         // [m11  m12] will point to RQ[i:(i+1), i:(i+1)]
         // [m21  m22]
         Scalar *m11 = RQ.data(), *m12, *m21, *m22,
-               *c = this->rot_cos.data(),
-               *s = this->rot_sin.data(),
+               *c = this->m_rot_cos.data(),
+               *s = this->m_rot_sin.data(),
                tmp;
-        for(int i = 0; i < this->n - 1; i++)
+        for(Index i = 0; i < this->m_n - 1; i++)
         {
             m21 = m11 + 1;
-            m12 = m11 + this->n;
+            m12 = m11 + this->m_n;
             m22 = m12 + 1;
             tmp = *m21;
 
