@@ -16,6 +16,7 @@
 #include <stdexcept>  // std::invalid_argument
 
 #include "SelectionRule.h"
+#include "CompInfo.h"
 #include "LinAlg/UpperHessenbergQR.h"
 #include "LinAlg/TridiagEigen.h"
 #include "MatOp/DenseGenMatProd.h"
@@ -97,7 +98,7 @@ namespace Spectra {
 ///
 ///     // Retrieve results
 ///     Eigen::VectorXd evalues;
-///     if(nconv > 0)
+///     if(eigs.info() == SUCCESSFUL)
 ///         evalues = eigs.eigenvalues();
 ///
 ///     std::cout << "Eigenvalues found:\n" << evalues << std::endl;
@@ -137,9 +138,12 @@ namespace Spectra {
 ///     SymEigsSolver<double, LARGEST_ALGE, MyDiagonalTen> eigs(&op, 3, 6);
 ///     eigs.init();
 ///     eigs.compute();
-///     Eigen::VectorXd evalues = eigs.eigenvalues();
-///     // Will get (10, 9, 8)
-///     std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     if(eigs.info() == SUCCESSFUL)
+///     {
+///         Eigen::VectorXd evalues = eigs.eigenvalues();
+///         // Will get (10, 9, 8)
+///         std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     }
 ///
 ///     return 0;
 /// }
@@ -160,77 +164,78 @@ private:
     typedef Eigen::SelfAdjointEigenSolver<Matrix> EigenSolver;
 
 protected:
-    OpType *op;          // object to conduct matrix operation,
-                         // e.g. matrix-vector product
+    OpType *m_op;          // object to conduct matrix operation,
+                           // e.g. matrix-vector product
 
 private:
-    const int dim_n;     // dimension of matrix A
+    const int m_n;         // dimension of matrix A
 
 protected:
-    const int nev;       // number of eigenvalues requested
+    const int m_nev;       // number of eigenvalues requested
 
 private:
-    const int ncv;       // number of ritz values
-    int nmatop;          // number of matrix operations called
-    int niter;           // number of restarting iterations
+    const int m_ncv;       // number of ritz values
+    int m_nmatop;          // number of matrix operations called
+    int m_niter;           // number of restarting iterations
 
-    Matrix fac_V;        // V matrix in the Arnoldi factorization
-    Matrix fac_H;        // H matrix in the Arnoldi factorization
-    Vector fac_f;        // residual in the Arnoldi factorization
+    Matrix m_fac_V;        // V matrix in the Arnoldi factorization
+    Matrix m_fac_H;        // H matrix in the Arnoldi factorization
+    Vector m_fac_f;        // residual in the Arnoldi factorization
 
 protected:
-    Vector ritz_val;     // ritz values
+    Vector m_ritz_val;     // ritz values
 
 private:
-    Matrix ritz_vec;     // ritz vectors
-    Vector ritz_est;     // last row of ritz_vec
-    BoolArray ritz_conv; // indicator of the convergence of ritz values
+    Matrix m_ritz_vec;     // ritz vectors
+    Vector m_ritz_est;     // last row of m_ritz_vec
+    BoolArray m_ritz_conv; // indicator of the convergence of ritz values
+    int m_info;            // status of the computation
 
-    const Scalar prec;   // precision parameter used to test convergence
-                         // prec = epsilon^(2/3)
-                         // epsilon is the machine precision,
-                         // e.g. ~= 1e-16 for the "double" type
+    const Scalar m_prec;   // precision parameter used to test convergence
+                           // m_prec = epsilon^(2/3)
+                           // epsilon is the machine precision,
+                           // e.g. ~= 1e-16 for the "double" type
 
     // Arnoldi factorization starting from step-k
     void factorize_from(int from_k, int to_m, const Vector &fk)
     {
         if(to_m <= from_k) return;
 
-        fac_f = fk;
+        m_fac_f = fk;
 
-        Vector w(dim_n);
-        Scalar beta = fac_f.norm(), Hii = 0.0;
+        Vector w(m_n);
+        Scalar beta = m_fac_f.norm(), Hii = 0.0;
         // Keep the upperleft k x k submatrix of H and set other elements to 0
-        fac_H.rightCols(ncv - from_k).setZero();
-        fac_H.block(from_k, 0, ncv - from_k, from_k).setZero();
+        m_fac_H.rightCols(m_ncv - from_k).setZero();
+        m_fac_H.block(from_k, 0, m_ncv - from_k, from_k).setZero();
         for(int i = from_k; i <= to_m - 1; i++)
         {
             // v <- f / ||f||
-            MapVec v(&fac_V(0, i), dim_n); // The (i+1)-th column
-            v.noalias() = fac_f / beta;
-            fac_H(i, i - 1) = beta;
+            MapVec v(&m_fac_V(0, i), m_n); // The (i+1)-th column
+            v.noalias() = m_fac_f / beta;
+            m_fac_H(i, i - 1) = beta;
 
             // w <- A * v
-            op->perform_op(v.data(), w.data());
-            nmatop++;
+            m_op->perform_op(v.data(), w.data());
+            m_nmatop++;
 
             Hii = v.dot(w);
-            fac_H(i - 1, i) = beta;
-            fac_H(i, i) = Hii;
+            m_fac_H(i - 1, i) = beta;
+            m_fac_H(i, i) = Hii;
 
             //  f <- w - V * V' * w
-            fac_f.noalias() = w - beta * fac_V.col(i - 1) - Hii * v;
-            beta = fac_f.norm();
+            m_fac_f.noalias() = w - beta * m_fac_V.col(i - 1) - Hii * v;
+            beta = m_fac_f.norm();
 
             // f/||f|| is going to be the next column of V, so we need to test
             // whether V' * (f/||f||) ~= 0
-            MapMat V(fac_V.data(), dim_n, i + 1); // The first (i+1) columns
-            Vector Vf = V.transpose() * fac_f;
-            if(Vf.cwiseAbs().maxCoeff() > prec * beta)
+            MapMat V(m_fac_V.data(), m_n, i + 1); // The first (i+1) columns
+            Vector Vf = V.transpose() * m_fac_f;
+            if(Vf.cwiseAbs().maxCoeff() > m_prec * beta)
             {
                 // f <- f - V * V' * f
-                fac_f.noalias() -= V * Vf;
-                beta = fac_f.norm();
+                m_fac_f.noalias() -= V * Vf;
+                beta = m_fac_f.norm();
             }
         }
     }
@@ -238,71 +243,71 @@ private:
     // Implicitly restarted Arnoldi factorization
     void restart(int k)
     {
-        if(k >= ncv)
+        if(k >= m_ncv)
             return;
 
         TridiagQR<Scalar> decomp;
-        Matrix Q = Matrix::Identity(ncv, ncv);
+        Matrix Q = Matrix::Identity(m_ncv, m_ncv);
 
-        for(int i = k; i < ncv; i++)
+        for(int i = k; i < m_ncv; i++)
         {
             // QR decomposition of H-mu*I, mu is the shift
-            fac_H.diagonal().array() -= ritz_val[i];
-            decomp.compute(fac_H);
+            m_fac_H.diagonal().array() -= m_ritz_val[i];
+            decomp.compute(m_fac_H);
 
             // Q -> Q * Qi
             decomp.apply_YQ(Q);
             // H -> Q'HQ
             // Since QR = H - mu * I, we have H = QR + mu * I
             // and therefore Q'HQ = RQ + mu * I
-            fac_H = decomp.matrix_RQ();
-            fac_H.diagonal().array() += ritz_val[i];
+            m_fac_H = decomp.matrix_RQ();
+            m_fac_H.diagonal().array() += m_ritz_val[i];
         }
         // V -> VQ, only need to update the first k+1 columns
         // Q has some elements being zero
         // The first (ncv - k + i) elements of the i-th column of Q are non-zero
-        Matrix Vs(dim_n, k + 1);
+        Matrix Vs(m_n, k + 1);
         int nnz;
         for(int i = 0; i < k; i++)
         {
-            nnz = ncv - k + i + 1;
-            MapMat V(fac_V.data(), dim_n, nnz);
+            nnz = m_ncv - k + i + 1;
+            MapMat V(m_fac_V.data(), m_n, nnz);
             MapVec q(&Q(0, i), nnz);
             Vs.col(i).noalias() = V * q;
         }
-        Vs.col(k).noalias() = fac_V * Q.col(k);
-        fac_V.leftCols(k + 1).noalias() = Vs;
+        Vs.col(k).noalias() = m_fac_V * Q.col(k);
+        m_fac_V.leftCols(k + 1).noalias() = Vs;
 
-        Vector fk = fac_f * Q(ncv - 1, k - 1) + fac_V.col(k) * fac_H(k, k - 1);
-        factorize_from(k, ncv, fk);
+        Vector fk = m_fac_f * Q(m_ncv - 1, k - 1) + m_fac_V.col(k) * m_fac_H(k, k - 1);
+        factorize_from(k, m_ncv, fk);
         retrieve_ritzpair();
     }
 
     // Calculate the number of converged Ritz values
     int num_converged(Scalar tol)
     {
-        // thresh = tol * max(prec, abs(theta)), theta for ritz value
-        Array thresh = tol * ritz_val.head(nev).array().abs().max(prec);
-        Array resid =  ritz_est.head(nev).array().abs() * fac_f.norm();
+        // thresh = tol * max(m_prec, abs(theta)), theta for ritz value
+        Array thresh = tol * m_ritz_val.head(m_nev).array().abs().max(m_prec);
+        Array resid =  m_ritz_est.head(m_nev).array().abs() * m_fac_f.norm();
         // Converged "wanted" ritz values
-        ritz_conv = (resid < thresh);
+        m_ritz_conv = (resid < thresh);
 
-        return ritz_conv.cast<int>().sum();
+        return m_ritz_conv.cast<int>().sum();
     }
 
     // Return the adjusted nev for restarting
     int nev_adjusted(int nconv)
     {
-        int nev_new = nev;
+        int nev_new = m_nev;
 
-        for(int i = nev; i < ncv; i++)
-            if(std::abs(ritz_est[i]) < prec)  nev_new++;
+        for(int i = m_nev; i < m_ncv; i++)
+            if(std::abs(m_ritz_est[i]) < m_prec)  nev_new++;
 
         // Adjust nev_new, according to dsaup2.f line 677~684 in ARPACK
-        nev_new += std::min(nconv, (ncv - nev_new) / 2);
-        if(nev_new == 1 && ncv >= 6)
-            nev_new = ncv / 2;
-        else if(nev_new == 1 && ncv > 2)
+        nev_new += std::min(nconv, (m_ncv - nev_new) / 2);
+        if(nev_new == 1 && m_ncv >= 6)
+            nev_new = m_ncv / 2;
+        else if(nev_new == 1 && m_ncv > 2)
             nev_new = 2;
 
         return nev_new;
@@ -311,7 +316,7 @@ private:
     // Retrieve and sort ritz values and ritz vectors
     void retrieve_ritzpair()
     {
-        TridiagEigen<Scalar> decomp(fac_H);
+        TridiagEigen<Scalar> decomp(m_fac_H);
         Vector evals = decomp.eigenvalues();
         Matrix evecs = decomp.eigenvectors();
 
@@ -329,26 +334,26 @@ private:
         if(SelectionRule == BOTH_ENDS)
         {
             std::vector<int> ind_copy(ind);
-            for(int i = 0; i < ncv; i++)
+            for(int i = 0; i < m_ncv; i++)
             {
                 // If i is even, pick values from the left (large values)
                 // If i is odd, pick values from the right (small values)
                 if(i % 2 == 0)
                     ind[i] = ind_copy[i / 2];
                 else
-                    ind[i] = ind_copy[ncv - 1 - i / 2];
+                    ind[i] = ind_copy[m_ncv - 1 - i / 2];
             }
         }
 
-        // Copy the ritz values and vectors to ritz_val and ritz_vec, respectively
-        for(int i = 0; i < ncv; i++)
+        // Copy the ritz values and vectors to m_ritz_val and m_ritz_vec, respectively
+        for(int i = 0; i < m_ncv; i++)
         {
-            ritz_val[i] = evals[ind[i]];
-            ritz_est[i] = evecs(ncv - 1, ind[i]);
+            m_ritz_val[i] = evals[ind[i]];
+            m_ritz_est[i] = evecs(m_ncv - 1, ind[i]);
         }
-        for(int i = 0; i < nev; i++)
+        for(int i = 0; i < m_nev; i++)
         {
-            ritz_vec.col(i) = evecs.col(ind[i]);
+            m_ritz_vec.col(i) = evecs.col(ind[i]);
         }
     }
 
@@ -358,7 +363,7 @@ protected:
     virtual void sort_ritzpair(int sort_rule)
     {
         // First make sure that we have a valid index vector
-        SortEigenvalue<Scalar, LARGEST_ALGE> sorting(ritz_val.data(), nev);
+        SortEigenvalue<Scalar, LARGEST_ALGE> sorting(m_ritz_val.data(), m_nev);
         std::vector<int> ind = sorting.index();
 
         switch(sort_rule)
@@ -367,19 +372,19 @@ protected:
                 break;
             case LARGEST_MAGN:
             {
-                SortEigenvalue<Scalar, LARGEST_MAGN> sorting(ritz_val.data(), nev);
+                SortEigenvalue<Scalar, LARGEST_MAGN> sorting(m_ritz_val.data(), m_nev);
                 ind = sorting.index();
             }
                 break;
             case SMALLEST_ALGE:
             {
-                SortEigenvalue<Scalar, SMALLEST_ALGE> sorting(ritz_val.data(), nev);
+                SortEigenvalue<Scalar, SMALLEST_ALGE> sorting(m_ritz_val.data(), m_nev);
                 ind = sorting.index();
             }
                 break;
             case SMALLEST_MAGN:
             {
-                SortEigenvalue<Scalar, SMALLEST_MAGN> sorting(ritz_val.data(), nev);
+                SortEigenvalue<Scalar, SMALLEST_MAGN> sorting(m_ritz_val.data(), m_nev);
                 ind = sorting.index();
             }
                 break;
@@ -387,20 +392,20 @@ protected:
                 throw std::invalid_argument("unsupported sorting rule");
         }
 
-        Vector new_ritz_val(ncv);
-        Matrix new_ritz_vec(ncv, nev);
-        BoolArray new_ritz_conv(nev);
+        Vector new_ritz_val(m_ncv);
+        Matrix new_ritz_vec(m_ncv, m_nev);
+        BoolArray new_ritz_conv(m_nev);
 
-        for(int i = 0; i < nev; i++)
+        for(int i = 0; i < m_nev; i++)
         {
-            new_ritz_val[i] = ritz_val[ind[i]];
-            new_ritz_vec.col(i) = ritz_vec.col(ind[i]);
-            new_ritz_conv[i] = ritz_conv[ind[i]];
+            new_ritz_val[i] = m_ritz_val[ind[i]];
+            new_ritz_vec.col(i) = m_ritz_vec.col(ind[i]);
+            new_ritz_conv[i] = m_ritz_conv[ind[i]];
         }
 
-        ritz_val.swap(new_ritz_val);
-        ritz_vec.swap(new_ritz_vec);
-        ritz_conv.swap(new_ritz_conv);
+        m_ritz_val.swap(new_ritz_val);
+        m_ritz_vec.swap(new_ritz_vec);
+        m_ritz_conv.swap(new_ritz_conv);
     }
 
 public:
@@ -422,18 +427,19 @@ public:
     ///             and is advised to take \f$ncv \ge 2\cdot nev\f$.
     ///
     SymEigsSolver(OpType *op_, int nev_, int ncv_) :
-        op(op_),
-        dim_n(op->rows()),
-        nev(nev_),
-        ncv(ncv_ > dim_n ? dim_n : ncv_),
-        nmatop(0),
-        niter(0),
-        prec(std::pow(std::numeric_limits<Scalar>::epsilon(), Scalar(2.0) / 3))
+        m_op(op_),
+        m_n(m_op->rows()),
+        m_nev(nev_),
+        m_ncv(ncv_ > m_n ? m_n : ncv_),
+        m_nmatop(0),
+        m_niter(0),
+        m_info(NOT_COMPUTED),
+        m_prec(std::pow(std::numeric_limits<Scalar>::epsilon(), Scalar(2.0) / 3))
     {
-        if(nev_ < 1 || nev_ > dim_n - 1)
+        if(nev_ < 1 || nev_ > m_n - 1)
             throw std::invalid_argument("nev must satisfy 1 <= nev <= n - 1, n is the size of matrix");
 
-        if(ncv_ <= nev_ || ncv_ > dim_n)
+        if(ncv_ <= nev_ || ncv_ > m_n)
             throw std::invalid_argument("ncv must satisfy nev < ncv <= n, n is the size of matrix");
     }
 
@@ -449,39 +455,39 @@ public:
     void init(const Scalar *init_resid)
     {
         // Reset all matrices/vectors to zero
-        fac_V.resize(dim_n, ncv);
-        fac_H.resize(ncv, ncv);
-        fac_f.resize(dim_n);
-        ritz_val.resize(ncv);
-        ritz_vec.resize(ncv, nev);
-        ritz_est.resize(ncv);
-        ritz_conv.resize(nev);
+        m_fac_V.resize(m_n, m_ncv);
+        m_fac_H.resize(m_ncv, m_ncv);
+        m_fac_f.resize(m_n);
+        m_ritz_val.resize(m_ncv);
+        m_ritz_vec.resize(m_ncv, m_nev);
+        m_ritz_est.resize(m_ncv);
+        m_ritz_conv.resize(m_nev);
 
-        fac_V.setZero();
-        fac_H.setZero();
-        fac_f.setZero();
-        ritz_val.setZero();
-        ritz_vec.setZero();
-        ritz_est.setZero();
-        ritz_conv.setZero();
+        m_fac_V.setZero();
+        m_fac_H.setZero();
+        m_fac_f.setZero();
+        m_ritz_val.setZero();
+        m_ritz_vec.setZero();
+        m_ritz_est.setZero();
+        m_ritz_conv.setZero();
 
-        nmatop = 0;
-        niter = 0;
+        m_nmatop = 0;
+        m_niter = 0;
 
-        Vector v(dim_n);
-        std::copy(init_resid, init_resid + dim_n, v.data());
+        Vector v(m_n);
+        std::copy(init_resid, init_resid + m_n, v.data());
         Scalar vnorm = v.norm();
-        if(vnorm < prec)
+        if(vnorm < m_prec)
             throw std::invalid_argument("initial residual vector cannot be zero");
         v /= vnorm;
 
-        Vector w(dim_n);
-        op->perform_op(v.data(), w.data());
-        nmatop++;
+        Vector w(m_n);
+        m_op->perform_op(v.data(), w.data());
+        m_nmatop++;
 
-        fac_H(0, 0) = v.dot(w);
-        fac_f = w - v * fac_H(0, 0);
-        fac_V.col(0) = v;
+        m_fac_H(0, 0) = v.dot(w);
+        m_fac_f = w - v * m_fac_H(0, 0);
+        m_fac_V.col(0) = v;
     }
 
     ///
@@ -493,7 +499,7 @@ public:
     ///
     void init()
     {
-        Vector init_resid = Vector::Random(dim_n);
+        Vector init_resid = Vector::Random(m_n);
         init_resid.array() -= 0.5;
         init(init_resid.data());
     }
@@ -519,14 +525,14 @@ public:
     int compute(int maxit = 1000, Scalar tol = 1e-10, int sort_rule = LARGEST_ALGE)
     {
         // The m-step Arnoldi factorization
-        factorize_from(1, ncv, fac_f);
+        factorize_from(1, m_ncv, m_fac_f);
         retrieve_ritzpair();
         // Restarting
         int i, nconv = 0, nev_adj;
         for(i = 0; i < maxit; i++)
         {
             nconv = num_converged(tol);
-            if(nconv >= nev)
+            if(nconv >= m_nev)
                 break;
 
             nev_adj = nev_adjusted(nconv);
@@ -535,20 +541,27 @@ public:
         // Sorting results
         sort_ritzpair(sort_rule);
 
-        niter += i + 1;
+        m_niter += i + 1;
+        m_info = (nconv >= m_nev) ? SUCCESSFUL : NOT_CONVERGING;
 
-        return std::min(nev, nconv);
+        return std::min(m_nev, nconv);
     }
 
+    ///
+    /// Retuning the status of the computation.
+    /// The full list of enumeration values can be found in \ref Enumerations.
+    ///
+    int info() { return m_info; }
+
     ///
     /// Returning the number of iterations used in the computation.
     ///
-    int num_iterations() { return niter; }
+    int num_iterations() { return m_niter; }
 
     ///
     /// Returning the number of matrix operations used in the computation.
     ///
-    int num_operations() { return nmatop; }
+    int num_operations() { return m_nmatop; }
 
     ///
     /// Returning the converged eigenvalues.
@@ -559,18 +572,18 @@ public:
     ///
     Vector eigenvalues()
     {
-        int nconv = ritz_conv.cast<int>().sum();
+        int nconv = m_ritz_conv.cast<int>().sum();
         Vector res(nconv);
 
         if(!nconv)
             return res;
 
         int j = 0;
-        for(int i = 0; i < nev; i++)
+        for(int i = 0; i < m_nev; i++)
         {
-            if(ritz_conv[i])
+            if(m_ritz_conv[i])
             {
-                res[j] = ritz_val[i];
+                res[j] = m_ritz_val[i];
                 j++;
             }
         }
@@ -589,25 +602,25 @@ public:
     ///
     Matrix eigenvectors(int nvec)
     {
-        int nconv = ritz_conv.cast<int>().sum();
+        int nconv = m_ritz_conv.cast<int>().sum();
         nvec = std::min(nvec, nconv);
-        Matrix res(dim_n, nvec);
+        Matrix res(m_n, nvec);
 
         if(!nvec)
             return res;
 
-        Matrix ritz_vec_conv(ncv, nvec);
+        Matrix ritz_vec_conv(m_ncv, nvec);
         int j = 0;
-        for(int i = 0; i < nev && j < nvec; i++)
+        for(int i = 0; i < m_nev && j < nvec; i++)
         {
-            if(ritz_conv[i])
+            if(m_ritz_conv[i])
             {
-                ritz_vec_conv.col(j) = ritz_vec.col(i);
+                ritz_vec_conv.col(j) = m_ritz_vec.col(i);
                 j++;
             }
         }
 
-        res.noalias() = fac_V * ritz_vec_conv;
+        res.noalias() = m_fac_V * ritz_vec_conv;
 
         return res;
     }
@@ -617,7 +630,7 @@ public:
     ///
     Matrix eigenvectors()
     {
-        return eigenvectors(nev);
+        return eigenvectors(m_nev);
     }
 };
 
@@ -701,9 +714,12 @@ public:
 ///
 ///     eigs.init();
 ///     eigs.compute();
-///     Eigen::VectorXd evalues = eigs.eigenvalues();
-///     // Will get (3.0, 2.0, 1.0)
-///     std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     if(eigs.info() == SUCCESSFUL)
+///     {
+///         Eigen::VectorXd evalues = eigs.eigenvalues();
+///         // Will get (3.0, 2.0, 1.0)
+///         std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     }
 ///
 ///     return 0;
 /// }
@@ -746,9 +762,12 @@ public:
 ///                        MyDiagonalTenShiftSolve> eigs(&op, 3, 6, 3.14);
 ///     eigs.init();
 ///     eigs.compute();
-///     Eigen::VectorXd evalues = eigs.eigenvalues();
-///     // Will get (4.0, 3.0, 2.0)
-///     std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     if(eigs.info() == SUCCESSFUL)
+///     {
+///         Eigen::VectorXd evalues = eigs.eigenvalues();
+///         // Will get (4.0, 3.0, 2.0)
+///         std::cout << "Eigenvalues found:\n" << evalues << std::endl;
+///     }
 ///
 ///     return 0;
 /// }
@@ -767,8 +786,8 @@ private:
     // First transform back the ritz values, and then sort
     void sort_ritzpair(int sort_rule)
     {
-        Array ritz_val_org = Scalar(1.0) / this->ritz_val.head(this->nev).array() + sigma;
-        this->ritz_val.head(this->nev) = ritz_val_org;
+        Array m_ritz_val_org = Scalar(1.0) / this->m_ritz_val.head(this->m_nev).array() + sigma;
+        this->m_ritz_val.head(this->m_nev) = m_ritz_val_org;
         SymEigsSolver<Scalar, SelectionRule, OpType>::sort_ritzpair(sort_rule);
     }
 public:
@@ -794,7 +813,7 @@ public:
         SymEigsSolver<Scalar, SelectionRule, OpType>(op_, nev_, ncv_),
         sigma(sigma_)
     {
-        this->op->set_shift(sigma);
+        this->m_op->set_shift(sigma);
     }
 };
 
